pub enum EvictionMode {
Off,
Auto,
Full,
}Expand description
Strategy for evicting evictable tasks from in-memory storage after a snapshot.
Variants
Off
Never evict.
Auto
Evict after a snapshot only once enough memory has been allocated since
the last eviction to justify the cost of restoring evicted tasks on
demand. Uses allocator statistics to estimate reclaimable memory.
See [EvictionControl::auto_threshold_exceeded].
Full
After every snapshot, evict all evictable tasks from memory, reloading them from disk on demand.