StartupCacheState

Enum StartupCacheState 

pub enum StartupCacheState {
    NoCache,
    Cached,
    Invalidated {
        reason_code: Option<String>,
    },
}
Information about if there’s was a pre-existing cache or if the cache was detected as invalidated during startup.

If the cache was invalidated, the application may choose to show a warning to the user or log it to telemetry.

This value is returned by crate::turbo_backing_storage.

Variants



NoCache



Cached



Invalidated

Fields

reason_code: Option<String>

A short code passed to BackingStorage::invalidate. This value is application-specific.

If the value is None or doesn’t match an expected value, the application should just treat this reason as unknown. The invalidation file may have been corrupted or modified by an external tool.

See invalidation_reasons for some common reason codes.