pub struct BackendOptions {
pub dependency_tracking: bool,
pub active_tracking: bool,
pub storage_mode: Option<StorageMode>,
pub num_workers: Option<usize>,
pub small_preallocation: bool,
pub eviction_mode: EvictionMode,
pub gc: Option<bool>,
pub gc_root_ttl: Option<Duration>,
pub gc_min_progress: Option<Duration>,
}Fields
dependency_tracking: boolEnables dependency tracking.
When disabled: No state changes are allowed. Tasks will never reexecute and stay cached forever.
active_tracking: boolEnables active tracking.
Automatically disabled when dependency_tracking is disabled.
When disabled: All tasks are considered as active.
storage_mode: Option<StorageMode>Enables the backing storage.
num_workers: Option<usize>Number of tokio worker threads. It will be used to compute the shard amount of parallel
datastructures. If None, it will use the available parallelism.
small_preallocation: boolAvoid big preallocations for faster startup. Should only be used for testing purposes.
eviction_mode: EvictionModeStrategy for evicting evictable tasks from in-memory storage after a snapshot. This reclaims memory by clearing persisted data that can be re-loaded from disk on demand.
gc: Option<bool>Overrides whether the reference-counting GC runs for this backend. None (default) derives
it from the TURBO_ENGINE_GC env var;
gc_root_ttl: Option<Duration>Overrides how long a GC root may go un-anchored before it ages out. None (default)
derives it from the TURBO_ENGINE_GC_ROOT_TTL_MS env var, falling back to
[DEFAULT_GC_ROOT_TTL].
gc_min_progress: Option<Duration>Overrides how long a GC pass runs before it will honour an interrupt.