pub struct TurboTasksBackend { /* private fields */ }Implementations
Sourceimpl TurboTasksBackend
impl TurboTasksBackend
Sourcepub fn invalidate_storage(&self, reason_code: &str) -> Result<()>
pub fn invalidate_storage(&self, reason_code: &str) -> Result<()>
Invalidates the persistent storage so that it will be deleted the next time a turbopack instance is created with the filesystem cache enabled.
reason_code should be one of the codes in
crate::db_invalidation::invalidation_reasons.
pub fn new( options: BackendOptions, backing_storage: TurboBackingStorage, ) -> Self